@@ -15,6 +15,7 @@ import re
 from astro_ghost.PS1QueryFunctions import getcolorim, get_hosts
 from astro_ghost.hostMatching import build_ML_df
 from astro_ghost.NEDQueryFunctions import getNEDInfo
+from astro_ghost.SimbadQueryFunctions import getSimbadInfo
 from astro_ghost.gradientAscent import gradientAscent
 from astro_ghost.starSeparation import separateStars_STRM, separateStars_South
 from astro_ghost.sourceCleaning import clean_dict, removePS1Duplicates, getColors, makeCuts
@@ -29,19 +30,21 @@ import astro_ghost
 from joblib import dump, load
 
 def getGHOST(real=False, verbose=False):
-    install_path = astro_ghost.__file__
-    install_path = install_path.split("/")[:-1]
-    install_path = "/".join(install_path)
-    if not os.path.exists(install_path + '/database'):
-        os.makedirs(install_path + '/database')
+    install_path = os.getenv('GHOST_PATH')
+    if not install_path:
+    	install_path = astro_ghost.__file__
+    	install_path = install_path.split("/")[:-1]
+   	install_path = "/".join(install_path)
+  	if not os.path.exists(install_path + '/database'):
+       		os.makedirs(install_path + '/database')
+        os.environ['GHOST_PATH'] = install_path
     if real:
-        #url = 'http://ghost.ncsa.illinois.edu/static/database/GHOST.csv'
-        url = 'https://www.dropbox.com/s/esytx5xpyegm1it/GHOST.csv?dl=1'
+        url = 'https://www.dropbox.com/s/a0fufc3827pfril/GHOST.csv?dl=1'
         r = requests.get(url)
         fname = install_path + '/database/GHOST.csv'
         open(fname , 'wb').write(r.content)
         if verbose:
-            print("Successfully downloaded GHOST database from ghost.ncsa.illinois.edu.\n")
+            print("Successfully downloaded GHOST database.\n")
     else:
         #create dummy database
         colnames = ['objName', 'objAltName1', 'objAltName2', 'objAltName3', 'objID',
@@ -451,9 +454,11 @@ def coneSearchPairs(coord, radius):
 # inputs: none
 # outputs: the full GHOST database
 def fullData():
-    install_path = astro_ghost.__file__
-    install_path = install_path.split("/")[:-1]
-    install_path = "/".join(install_path)
+    install_path = os.getenv('GHOST_PATH')
+    if not install_path:
+    	install_path = astro_ghost.__file__
+    	install_path = install_path.split("/")[:-1]
+    	install_path = "/".join(install_path)
     fullTable = pd.read_csv(install_path+"/database/GHOST.csv")
     return fullTable
 
@@ -466,6 +471,13 @@ def fullData():
 #         with stats provided at
 #         printout
 def getTransientHosts(snName=[''], snCoord=[''], snClass=[''], verbose=0, starcut='normal', ascentMatch=False, px=800, savepath='./'):
+ 
+    #if no names were passed in, add placeholder names for each transient in the search 
+    if snName == ['']:
+        snName = []
+        print("No transient names listed, adding placeholder names...")
+        for i in np.arange(len(snCoord)):
+            snName.append("Transient_%i" % (i+1))
     hostDB = None
     tempHost1 = tempHost2 = tempHost3 = None
     found_by_name = found_by_coord = found_by_manual = 0
@@ -540,7 +552,7 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
     #dateStr = "%i%.02i%.02i" % (now.year,now.month,now.day)
     dateStr = str(datetime.today()).replace("-", '').replace(".", '').replace(":", "").replace(" ", '')
 
-    rad = 30 #arcsec
+    rad = 60 #arcsec
     fn_Host = "SNe_TNS_%s_PS1Hosts_%iarcsec.csv" % (dateStr, rad)
     fn_SN = 'transients_%s.csv' % dateStr
     fn_Dict = fn_Host[:-4] + ".p"
@@ -601,6 +613,8 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle', ascentMa
 
     host_DF = pd.concat([host_DF_north, host_DF_south], ignore_index=True)
     host_DF = getNEDInfo(host_DF)
+    host_DF = getSimbadInfo(host_DF)
+    host_DF.to_csv(path+"/candidateHosts_NEDSimbad.csv", index=False)
 
     host_DF_north = host_DF[host_DF['decMean']>-30].reset_index()
     host_DF_south = host_DF[host_DF['decMean']<=-30].reset_index()
