@@ -89,6 +89,15 @@ coneSearchPairs(supernovaCoord[0], 1.e3)
 #GHOST = pd.read_csv("/Users/agagliano/Documents/Research/GHOST/Data/database/GHOST.tar.gz")
 GHOST.to_csv("/Users/agagliano/Documents/Research/GHOST/Data/database/GHOST.csv",index=False)
 
+THEx_hosts_PS1 = pd.DataFrame(np.load("/Users/agagliano/Documents/Teaching/Holly/THEx-v8.0-release-NumPy-export/THEx-v8.0-release-assembled-PS1v2.npy"))
+THEx_hosts_index = pd.DataFrame(np.load("/Users/agagliano/Documents/Teaching/Holly/THEx-v8.0-release-NumPy-export/THEx-v8.0-release-assembled-index.npy"))
+
+THEx_hosts_PS1 = THEx_hosts_index.merge(THEx_hosts_PS1)
+THEx_hosts_PS1.rename(columns={'event_dec':'TransientRA', 'event_ra':'TransientRA', 'event_name':'TransientName'}, inplace=True)
+
+THEx_hosts_PS1.rename(columns={'event_z':'photo_z'},inplace=True)
+THEx_hosts_PS1.to_csv("/Users/agagliano/Documents/Teaching/Holly/THEx-v8.0-release-NumPy-export/THEx_PS1.tar.gz",index=False)
+
 url = 'https://www.dropbox.com/s/7bim5sssnw9w6pg/MLP_lupton.hdf5?dl=1'
 fname = 'MLP_lupton.hdf5'
 response = requests.get(url, stream=True)
